### 0.10.7 {small}`2024-07-23`

```{rubric} Features
```
* adds `decoupler_gpu.run_ulm` {pr}`224` {smaller}`S Dicks`

```{rubric} Performance
```
* adds `_sparse2dense` for better performance {pr}`220` {smaller}`S Dicks`
* refactors `regress_out` {pr}`222` {smaller}`S Dicks`
* refactors `decoupler_gpu` dataloading {pr}`224` {smaller}`S Dicks`
* updates `regress_out` for better memory use {pr}`227` {smaller}`S Dicks`
* avoid `.toarray()` in sparse PCA transform {pr}`228` {smaller}`S Dicks`


```{rubric} Bug fixes
```
* Removes support for older rapids with `tl.louvain` that cause issues {pr}`226` {smaller}`S Dicks`
